/*******************************************************************************
* File Name: P00.c  
* Version 2.5
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "P00.h"


/*******************************************************************************
* Function Name: P00_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void P00_Write(uint8 value) 
{
    uint8 staticBits = (P00_DR & (uint8)(~P00_MASK));
    P00_DR = staticBits | ((uint8)(value << P00_SHIFT) & P00_MASK);
}


/*******************************************************************************
* Function Name: P00_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  P00_DM_STRONG     Strong Drive 
*  P00_DM_OD_HI      Open Drain, Drives High 
*  P00_DM_OD_LO      Open Drain, Drives Low 
*  P00_DM_RES_UP     Resistive Pull Up 
*  P00_DM_RES_DWN    Resistive Pull Down 
*  P00_DM_RES_UPDWN  Resistive Pull Up/Down 
*  P00_DM_DIG_HIZ    High Impedance Digital 
*  P00_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void P00_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(P00_0, mode);
}


/*******************************************************************************
* Function Name: P00_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro P00_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 P00_Read(void) 
{
    return (P00_PS & P00_MASK) >> P00_SHIFT;
}


/*******************************************************************************
* Function Name: P00_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 P00_ReadDataReg(void) 
{
    return (P00_DR & P00_MASK) >> P00_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(P00_INTSTAT) 

    /*******************************************************************************
    * Function Name: P00_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 P00_ClearInterrupt(void) 
    {
        return (P00_INTSTAT & P00_MASK) >> P00_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
