/*******************************************************************************
* File Name: P20.c  
* Version 2.5
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "P20.h"


/*******************************************************************************
* Function Name: P20_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void P20_Write(uint8 value) 
{
    uint8 staticBits = (P20_DR & (uint8)(~P20_MASK));
    P20_DR = staticBits | ((uint8)(value << P20_SHIFT) & P20_MASK);
}


/*******************************************************************************
* Function Name: P20_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  P20_DM_STRONG     Strong Drive 
*  P20_DM_OD_HI      Open Drain, Drives High 
*  P20_DM_OD_LO      Open Drain, Drives Low 
*  P20_DM_RES_UP     Resistive Pull Up 
*  P20_DM_RES_DWN    Resistive Pull Down 
*  P20_DM_RES_UPDWN  Resistive Pull Up/Down 
*  P20_DM_DIG_HIZ    High Impedance Digital 
*  P20_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void P20_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(P20_0, mode);
}


/*******************************************************************************
* Function Name: P20_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro P20_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 P20_Read(void) 
{
    return (P20_PS & P20_MASK) >> P20_SHIFT;
}


/*******************************************************************************
* Function Name: P20_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 P20_ReadDataReg(void) 
{
    return (P20_DR & P20_MASK) >> P20_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(P20_INTSTAT) 

    /*******************************************************************************
    * Function Name: P20_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 P20_ClearInterrupt(void) 
    {
        return (P20_INTSTAT & P20_MASK) >> P20_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
