/*******************************************************************************
* File Name: P27.c  
* Version 2.5
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "P27.h"


/*******************************************************************************
* Function Name: P27_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void P27_Write(uint8 value) 
{
    uint8 staticBits = (P27_DR & (uint8)(~P27_MASK));
    P27_DR = staticBits | ((uint8)(value << P27_SHIFT) & P27_MASK);
}


/*******************************************************************************
* Function Name: P27_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  P27_DM_STRONG     Strong Drive 
*  P27_DM_OD_HI      Open Drain, Drives High 
*  P27_DM_OD_LO      Open Drain, Drives Low 
*  P27_DM_RES_UP     Resistive Pull Up 
*  P27_DM_RES_DWN    Resistive Pull Down 
*  P27_DM_RES_UPDWN  Resistive Pull Up/Down 
*  P27_DM_DIG_HIZ    High Impedance Digital 
*  P27_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void P27_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(P27_0, mode);
}


/*******************************************************************************
* Function Name: P27_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro P27_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 P27_Read(void) 
{
    return (P27_PS & P27_MASK) >> P27_SHIFT;
}


/*******************************************************************************
* Function Name: P27_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 P27_ReadDataReg(void) 
{
    return (P27_DR & P27_MASK) >> P27_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(P27_INTSTAT) 

    /*******************************************************************************
    * Function Name: P27_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 P27_ClearInterrupt(void) 
    {
        return (P27_INTSTAT & P27_MASK) >> P27_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
