/*******************************************************************************
* File Name: P42.c  
* Version 2.5
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "P42.h"


/*******************************************************************************
* Function Name: P42_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void P42_Write(uint8 value) 
{
    uint8 staticBits = (P42_DR & (uint8)(~P42_MASK));
    P42_DR = staticBits | ((uint8)(value << P42_SHIFT) & P42_MASK);
}


/*******************************************************************************
* Function Name: P42_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  P42_DM_STRONG     Strong Drive 
*  P42_DM_OD_HI      Open Drain, Drives High 
*  P42_DM_OD_LO      Open Drain, Drives Low 
*  P42_DM_RES_UP     Resistive Pull Up 
*  P42_DM_RES_DWN    Resistive Pull Down 
*  P42_DM_RES_UPDWN  Resistive Pull Up/Down 
*  P42_DM_DIG_HIZ    High Impedance Digital 
*  P42_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void P42_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(P42_0, mode);
}


/*******************************************************************************
* Function Name: P42_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro P42_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 P42_Read(void) 
{
    return (P42_PS & P42_MASK) >> P42_SHIFT;
}


/*******************************************************************************
* Function Name: P42_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 P42_ReadDataReg(void) 
{
    return (P42_DR & P42_MASK) >> P42_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(P42_INTSTAT) 

    /*******************************************************************************
    * Function Name: P42_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 P42_ClearInterrupt(void) 
    {
        return (P42_INTSTAT & P42_MASK) >> P42_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
