/*******************************************************************************
* File Name: P60.c  
* Version 2.5
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "P60.h"


/*******************************************************************************
* Function Name: P60_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void P60_Write(uint8 value) 
{
    uint8 staticBits = (P60_DR & (uint8)(~P60_MASK));
    P60_DR = staticBits | ((uint8)(value << P60_SHIFT) & P60_MASK);
}


/*******************************************************************************
* Function Name: P60_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  P60_DM_STRONG     Strong Drive 
*  P60_DM_OD_HI      Open Drain, Drives High 
*  P60_DM_OD_LO      Open Drain, Drives Low 
*  P60_DM_RES_UP     Resistive Pull Up 
*  P60_DM_RES_DWN    Resistive Pull Down 
*  P60_DM_RES_UPDWN  Resistive Pull Up/Down 
*  P60_DM_DIG_HIZ    High Impedance Digital 
*  P60_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void P60_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(P60_0, mode);
}


/*******************************************************************************
* Function Name: P60_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro P60_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 P60_Read(void) 
{
    return (P60_PS & P60_MASK) >> P60_SHIFT;
}


/*******************************************************************************
* Function Name: P60_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 P60_ReadDataReg(void) 
{
    return (P60_DR & P60_MASK) >> P60_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(P60_INTSTAT) 

    /*******************************************************************************
    * Function Name: P60_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 P60_ClearInterrupt(void) 
    {
        return (P60_INTSTAT & P60_MASK) >> P60_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
